
#' @importFrom SSBtools GaussSuppression
#' @export
SSBtools::GaussSuppression


#' @importFrom SSBtools SSBtoolsData
#' @export
SSBtools::SSBtoolsData

#' @importFrom SSBtools FormulaSelection
#' @export
SSBtools::FormulaSelection

#' @importFrom SSBtools formula_selection
#' @export
SSBtools::formula_selection

#' @importFrom SSBtools tables_by_formulas
#' @export
SSBtools::tables_by_formulas


